retrieveDeltaForMonth method
Returns the number of days to skip at the beginning of the current month.
Implementation
int retrieveDeltaForMonth() {
return controller.retrieveDeltaForMonth(currentMonth);
}
Returns the number of days to skip at the beginning of the current month.
int retrieveDeltaForMonth() {
return controller.retrieveDeltaForMonth(currentMonth);
}