retrieveDeltaForNextMonth method
Returns the number of days to skip at the beginning of the next month.
Implementation
int retrieveDeltaForNextMonth() {
return controller.retrieveDeltaForMonth(nextMonth);
}
Returns the number of days to skip at the beginning of the next month.
int retrieveDeltaForNextMonth() {
return controller.retrieveDeltaForMonth(nextMonth);
}