DateRange class

A model that represents a date range. It is used to represent the selected date range in the calendar.

  • start - The start date of the date range.
  • end - The end date of the date range.
  • duration - The duration of the date range in days.

Constructors

DateRange(DateTime start, DateTime end)

Properties

duration int
Returns the duration of the date range in days.
no setter
end DateTime
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start DateTime
final

Methods

contains(DateTime date) bool
Returns whether the date range contains the given date or not.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override