duration property
int
get
duration
Returns the duration of the date range in days.
Implementation
int get duration => end.difference(start).inDays;
Returns the duration of the date range in days.
int get duration => end.difference(start).inDays;