MonthSelectorAndDoubleIndicator class

A widget that displays the current and next month in a row along with navigation arrows.

Inheritance

Constructors

MonthSelectorAndDoubleIndicator({Key? key, required DateTime currentMonth, required VoidCallback onNext, required VoidCallback onPrevious, DateTime? nextMonth, TextStyle? style, bool doubleMonth = true})
const

Properties

currentMonth DateTime
The current month displayed.
final
doubleMonth bool
Whether to display two months or not.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
nextMonth DateTime?
The next month displayed.
final
onNext VoidCallback
A callback for when the next button is pressed.
final
onPrevious VoidCallback
A callback for when the previous button is pressed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style TextStyle?
The text style of the displayed month.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited