selectedDateRange property
The dateRange that is currently selected. A line will be displayed on the left using the CalendarTheme.selectedQuickDateRangeColor color.
Implementation
final DateRange? selectedDateRange;
The dateRange that is currently selected. A line will be displayed on the left using the CalendarTheme.selectedQuickDateRangeColor color.
final DateRange? selectedDateRange;