DateRange class
A model that represents a date range. It is used to represent the selected date range in the calendar.
Properties
Methods
-
contains(
DateTime date) → bool -
Returns whether the date range contains the given
dateor not. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override