DateRangeField class
A StatelessWidget that provides a field to select a date range dateRange.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- DateRangeField
Constructors
-
DateRangeField({Key? key, InputDecoration? decoration, DateRange? selectedDateRange, ValueChanged<
DateRange?> ? onDateRangeSelected, Widget childBuilder(BuildContext, DateRange?)?, bool enabled = true, required String cancelText, required String confirmText, required DateRangerPickerWidgetBuilder pickerBuilder, Future<DateRange?> showDateRangePicker({required String cancelText, required String confirmText, required DateRangerPickerWidgetBuilder pickerBuilder, required BuildContext widgetContext}) = showDateRangePickerDialogOnWidget}) -
Creates a DateRangeField.
const
Properties
- cancelText → String
-
final
- childBuilder → Widget Function(BuildContext, DateRange?)?
-
final
- confirmText → String
-
final
- decoration → InputDecoration?
-
final
-
final
- enabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onDateRangeSelected
→ ValueChanged<
DateRange?> ? -
final
- pickerBuilder → DateRangerPickerWidgetBuilder
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedDateRange → DateRange?
-
final
-
showDateRangePicker
→ Future<
DateRange?> Function({required String cancelText, required String confirmText, required DateRangerPickerWidgetBuilder pickerBuilder, required BuildContext widgetContext}) -
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
generateOnTap(
BuildContext context) → VoidCallback? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited